| Title: | An R package for diagnosing movement data quality |
|---|---|
| Description: | An R package for diagnosing movement data quality. |
| Authors: | Mikkel Roald-Arbøl [aut, cre] (ORCID: <https://orcid.org/0000-0002-9998-0058>) |
| Maintainer: | Mikkel Roald-Arbøl <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-06-03 06:49:24 UTC |
| Source: | https://github.com/animovement/anicheck |
check_confidence() computes summary statistics for confidence values
grouped by a chosen variable (defaulting to keypoint) and returns a
tidy data frame that can be visualized with standard plotting functions.
check_confidence(data, ...) ## Default S3 method: check_confidence(data, by = NULL, ...)check_confidence(data, ...) ## Default S3 method: check_confidence(data, by = NULL, ...)
data |
A data frame that contains at least the columns
|
... |
Arguments passed down to the plotting functions. |
by |
(Optional) A character vector or column name(s) used to
group the data before summarising. If |
A tibble/data frame with one row per group defined by by,
containing the following columns:
Median of confidence within the group (NA-removed).
First quartile (25th percentile) of confidence.
Third quartile (75th percentile) of confidence.
Minimum value of confidence within the group (NA-removed).
Maximum value of confidence within the group (NA-removed).
The result can be passed directly to ggplot2 or other visualization
packages.